@@ -15,7 +15,7 @@ use Encode;
 use App::Mobirc;
 use App::Mobirc::Util;
 use Module::Reload;
-use Config::Tiny;
+use YAML::Syck;
 
 our %IRSSI = ( name => 'mobirc' );
 
@@ -133,7 +133,7 @@ sub irssi_print_text {
     my ($dest, $text, $stripped) = @{ $poe->args->[1] };
 
     if ($dest->{level} & MSGLEVEL_HILIGHT) {
-        App::Mobirc::Model::Channel->update_keyword_buffer($poe->heap->{__last_row});
+        App::Mobirc::Model::Channel->update_keyword_buffer($poe->heap->{mobirc}, $poe->heap->{__last_row});
     }
 }
 
@@ -250,7 +250,7 @@ sub poe_initialize_mobirc {
 
     my $conffname = Irssi::settings_get_str('mobirc_config_path');
     unless ($conffname) {
-        Irssi::print('mobirc_config_path is not defined, please do "/set mobirc_config_path your_ini_path" first');
+        Irssi::print('mobirc_config_path is not defined, please do "/set mobirc_config_path your_yaml_path" first');
         return;
     }
     unless (-f $conffname && -r _) {
@@ -259,7 +259,7 @@ sub poe_initialize_mobirc {
     }
 
     my $mobirc;
-    eval { $mobirc = App::Mobirc->new(config => $conffname) };
+    eval { $mobirc = App::Mobirc->new($conffname) };
     if ($@) {
         Irssi::print("can't initialize mobirc: $@");
         return;
@@ -268,10 +268,10 @@ sub poe_initialize_mobirc {
     $poe->heap->{mobirc} = $mobirc;
     $poe->heap->{config} = $mobirc->config;
 
-    $mobirc->add_channel( App::Mobirc::Model::Channel->new(name => U '*server*') );
+    $mobirc->add_channel( App::Mobirc::Model::Channel->new($mobirc, U '*server*') );
     for my $channel (Irssi::channels()) {
         my $channel_name = normalize_channel_name(decode_utf8 $channel->{name});
-        $mobirc->add_channel( App::Mobirc::Model::Channel->new(name => $channel_name) );
+        $mobirc->add_channel( App::Mobirc::Model::Channel->new($mobirc, $channel_name) );
     }
 
     $mobirc;
@@ -332,24 +332,20 @@ mobirc.pl - irssi plugin for Mobirc
     
     2. run irssi with Mobirc
     
-       PERL5LIB=/path/to/mobirc/lib:/path/to/mobirc/extlib/ irssi
+       PERL5LIB=/path/to/mobirc/lib irssi
     
     3. start script in irssi
     
        /run mobirc
     
-    4. set config.ini path
+    4. set config.yaml path
     
-       /set mobirc_config_path /path/to/your/config.ini
+       /set mobirc_config_path /path/to/your/config.yaml
     
     5. start mobirc
     
        /mobirc start
 
-=head1 KNOWN BUGS
-
-irssi dumps core at exit irssi. anyone can fix this?
-
 =head1 AUTHOR
 
 Daisuke Murase <typester@cpan.org>
