@@ -1,5 +1,5 @@
 package App::Mobirc::Model::Channel;
-use Mouse;
+use Moose;
 use Scalar::Util qw/blessed/;
 use Carp;
 use List::MoreUtils qw/any all/;
@@ -28,12 +28,23 @@ has topic => (
     default => '',
 );
 
+has global_context => (
+    is      => 'rw',
+    isa     => 'App::Mobirc',
+    default => sub { App::Mobirc->context },
+);
+
 has name => (
     is       => 'rw',
     isa      => 'Str',
     required => 1,
 );
 
+around 'new' => sub {
+    my ($next, $class, $trash, $name) = @_;
+    $next->($class, name => $name);
+};
+
 sub add_message {
     my ($self, $message) = @_;
 
@@ -48,9 +59,9 @@ sub add_message {
 
     # update keyword buffer.
     if ($message->class eq 'public' && $self->name ne '*keyword*') {
-        if ((any { $message->body =~ /$_/i } @{global_context->config->{global}->{keywords} || []})
-         && (all { $message->body !~ /$_/i } @{global_context->config->{global}->{stopwords} || ["\0"]})) {
-            App::Mobirc::Model::Channel->update_keyword_buffer($message);
+        if ((any { $message->body =~ /$_/i } @{$self->{global_context}->config->{global}->{keywords} || []})
+         && (all { $message->body !~ /$_/i } @{$self->{global_context}->config->{global}->{stopwords} || ["\0"]})) {
+            App::Mobirc::Model::Channel->update_keyword_buffer($self->{global_context}, $message);
         }
     }
 }
@@ -58,7 +69,7 @@ sub add_message {
 sub _add_to_log {
     my ($self, $key, $row) = @_;
 
-    my $log_max = global_context->config->{global}->{log_max} || 20;
+    my $log_max = $self->{global_context}->config->{httpd}->{lines} || 20;
 
     push @{$self->{$key}}, $row;
     if ( @{$self->{$key}} > $log_max ) {
@@ -67,11 +78,12 @@ sub _add_to_log {
 }
 
 sub update_keyword_buffer {
-    my ($class, $message) = @_;
+    my ($class, $global_context, $message) = @_;
     croak "this is class method" if blessed $class;
+    croak "global context required" unless blessed $global_context;
 
     DEBUG "UPDATE KEYWORD: $message";
-    global_context->get_channel(U '*keyword*')->add_message( $message );
+    $global_context->get_channel(U '*keyword*')->add_message( $message );
 }
 
 sub unread_lines {
@@ -91,7 +103,7 @@ sub clear_unread {
 sub post_command {
     my ($self, $command) = @_;
 
-    global_context->run_hook_first('process_command', $command, $self);
+    $self->{global_context}->run_hook_first('process_command', $command, $self);
 }
 
 sub recent_log_count {
